; Create shadowed thumbnail for The GIMP
;
; Create shadowed thumbnail creates a thumbnail of an image with a shadow effect.
;
; The script is located in "<Image> / Web / Create shadowed thumbnail..."
;
; Last changed: 2009-02-09
;
; Copyright (C) 2009 Tommaso Frazzetto <tommaso.frazzetto@gmail.com>
; Project's web page: http://www.brainspace.it
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.  
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, you can view the GNU General Public
; License version 2 at the web site http://www.gnu.org/licenses/gpl-2.0.html
; Alternatively you can write to the Free Software Foundation, Inc., 675 Mass
; Ave, Cambridge, MA 02139, USA.
;
;
;


;Declare the script's main function
(define (script-fu-create-thumb 	theImage
					theLayer
					thumbWidth
					thumbHeight
 					shadowColor
					backgroundColor
					)

    ;Initiate some variables
    (let* (
	(layerBackground 0)
	(layerShadow 0)		
	(innertWidth (- thumbWidth 10))
        (innertHeight (- thumbHeight 10))
    )

    ;Start an undo group so the process can be undone with one undo
    (gimp-image-undo-group-start theImage)
   
    ;Select none
    (gimp-selection-none theImage)

    ;Resize image to thumb size
    (gimp-image-scale-full theImage innertWidth innertHeight 2)
    
    ; Create shadow layer
    (set! layerShadow (car (gimp-layer-new theImage innertWidth innertHeight 0 "Shadow layer" 100.0 0)))

    ;Add shadow layer to image 
    (gimp-image-add-layer theImage layerShadow -1)

    ; Change shadow color
    (gimp-context-set-background shadowColor)

    ; Paint shadow layer
    (gimp-drawable-fill layerShadow BG-IMAGE-FILL)
    
    ; Move layer below
    (gimp-image-lower-layer-to-bottom theImage layerShadow)

    ; Rezize image
    (gimp-image-resize theImage thumbWidth thumbHeight 5 5)

    ; Create background layer
    (set! layerBackground (car (gimp-layer-new theImage thumbWidth thumbHeight 0 "Background layer" 100.0 0)))

    ;Add background layer to image 
    (gimp-image-add-layer theImage layerBackground -1)

    ; Change background color
    (gimp-context-set-background backgroundColor)

    ; Paint background layer
    (gimp-drawable-fill layerBackground BG-IMAGE-FILL)

    ; Move background layer below
    (gimp-image-lower-layer-to-bottom theImage layerBackground)

    ; resize shadow layer
    (gimp-layer-resize-to-image-size layerShadow)

    ; Blur shadow
    (plug-in-gauss 1 theImage layerShadow 6 6 1)

    ;Finish the undo group for the process
    (gimp-image-undo-group-end theImage)

    ;Ensure the updated image is displayed now
    (gimp-displays-flush)
    )
)

;Add script menu voice
(script-fu-register "script-fu-create-thumb"
            _"<Image>/Filters/Web/Shadowed thumbnail..."
            "Creates a thumbnail of an image with a shadow effect."
    	    "Tommaso Frazzetto"
            "Copyright 2009, Tommaso Frazzetto"
            "30 March 2009"
            "*"
            SF-IMAGE		"Image"     0
            SF-DRAWABLE		"Drawable"  0
	    SF-ADJUSTMENT	_"Thumbnail Width"      '(240 5 10000 1 1 0 1)
	    SF-ADJUSTMENT	_"Thumbnail Height"      '(180 5 10000 1 1 0 1)
	    SF-COLOR            _"Shadow Color"        '(0 0 0)
	    SF-COLOR            _"Background Color"        '(255 255 255)
)

